@@ -1,4 +1,4 @@
-#   Copyright 2020-2020 Exactpro (Exactpro Systems Limited)
+#   Copyright 2020-2021 Exactpro (Exactpro Systems Limited)
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -12,7 +12,6 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 
-
 from abc import ABC, abstractmethod
 from threading import Lock
 
@@ -20,7 +19,7 @@ from th2_common.schema.exception.router_error import RouterError
 from th2_common.schema.filter.strategy.filter_strategy import FilterStrategy
 from th2_common.schema.filter.strategy.impl.default_filter_strategy import DefaultFilterStrategy
 from th2_common.schema.message.configuration.queue_configuration import QueueConfiguration
-from th2_common.schema.message.impl.rabbitmq.configuration.rabbitmq_configuration import RabbitMQConfiguration
+from th2_common.schema.message.impl.rabbitmq.connection.connection_manager import ConnectionManager
 from th2_common.schema.message.message_listener import MessageListener
 from th2_common.schema.message.message_queue import MessageQueue
 from th2_common.schema.message.message_router import MessageRouter
@@ -51,9 +50,8 @@ class MultiplySubscribeMonitorImpl(SubscriberMonitor):
 
 class AbstractRabbitMessageRouter(MessageRouter, ABC):
 
-    def __init__(self, connection, rabbit_mq_configuration, configuration) -> None:
-        super().__init__(rabbit_mq_configuration, configuration)
-        self.connection = connection
+    def __init__(self, connection_manager, configuration) -> None:
+        super().__init__(connection_manager, configuration)
         self._filter_strategy = DefaultFilterStrategy()
         self.queue_connections = dict()
         self.queue_connections_lock = Lock()
@@ -75,8 +73,8 @@ class AbstractRabbitMessageRouter(MessageRouter, ABC):
         return self.required_send_attributes.union(queue_attr)
 
     def _subscribe_by_alias(self, callback: MessageListener, queue_alias) -> SubscriberMonitor:
-        queue = self._get_message_queue(self.connection, queue_alias)
-        subscriber = queue.get_subscriber()
+        queue: MessageQueue = self._get_message_queue(queue_alias)
+        subscriber: MessageSubscriber = queue.get_subscriber()
         subscriber.add_listener(callback)
         try:
             subscriber.start()
@@ -113,15 +111,13 @@ class AbstractRabbitMessageRouter(MessageRouter, ABC):
         self.unsubscribe_all()
 
     def send(self, message, *queue_attr):
-        if not queue_attr:
-            self._send_by_aliases_and_messages_to_send(self._find_by_filter(self.configuration.queues, message))
-            return
-
         attrs = self.add_send_attributes(queue_attr)
         filtered_by_attr = self.configuration.find_queues_by_attr(attrs)
         filtered_by_attr_and_filter = self._find_by_filter(filtered_by_attr, message)
         if len(filtered_by_attr_and_filter) != 1:
-            raise Exception('Wrong amount of queues for send_by_attr. Must be equal to 1')
+            raise Exception(f'Wrong amount of queues for send. Must be equal to 1. '
+                            f'Found {len(filtered_by_attr_and_filter)} queues, but must be only 1. '
+                            f'Search was done by {attrs} attributes')
         self._send_by_aliases_and_messages_to_send(filtered_by_attr_and_filter)
 
     def send_all(self, message, *queue_attr):
@@ -129,14 +125,15 @@ class AbstractRabbitMessageRouter(MessageRouter, ABC):
         filtered_by_attr = self.configuration.find_queues_by_attr(attrs)
         filtered_by_attr_and_filter = self._find_by_filter(filtered_by_attr, message)
         if len(filtered_by_attr_and_filter) == 0:
-            raise Exception('Wrong amount of queues for send_all. Must not be equal to 0')
+            raise Exception(f'Wrong amount of queues for send_all. Must not be equal to 0. '
+                            f'Search was done by {attrs} attributes')
         self._send_by_aliases_and_messages_to_send(filtered_by_attr_and_filter)
 
     def set_filter_strategy(self, filter_strategy: FilterStrategy):
         self._filter_strategy = filter_strategy
 
     @abstractmethod
-    def _create_queue(self, connection, configuration: RabbitMQConfiguration,
+    def _create_queue(self, connection_manager: ConnectionManager,
                       queue_configuration: QueueConfiguration) -> MessageQueue:
         pass
 
@@ -145,19 +142,18 @@ class AbstractRabbitMessageRouter(MessageRouter, ABC):
         pass
 
     def _send_by_aliases_and_messages_to_send(self, aliases_and_messages_to_send: dict):
-        for queue_alias in aliases_and_messages_to_send.keys():
-            message = aliases_and_messages_to_send[queue_alias]
+        for queue_alias, message in aliases_and_messages_to_send.items():
             try:
-                sender = self._get_message_queue(self.connection, queue_alias).get_sender()
+                sender = self._get_message_queue(queue_alias).get_sender()
                 sender.start()
                 sender.send(message)
-            except Exception as e:
-                raise RouterError('Can not start sender', e)
+            except Exception:
+                raise RouterError('Can not start sender')
 
-    def _get_message_queue(self, connection, queue_alias):
+    def _get_message_queue(self, queue_alias) -> MessageQueue:
         with self.queue_connections_lock:
-            if not self.queue_connections.__contains__(queue_alias):
-                self.queue_connections[queue_alias] = self._create_queue(connection, self.rabbit_mq_configuration,
+            if queue_alias not in self.queue_connections:
+                self.queue_connections[queue_alias] = self._create_queue(self.connection_manager,
                                                                          self.configuration.get_queue_by_alias(
                                                                              queue_alias))
             return self.queue_connections[queue_alias]
