@@ -1,4 +1,4 @@
-#   Copyright 2020-2020 Exactpro (Exactpro Systems Limited)
+#   Copyright 2020-2021 Exactpro (Exactpro Systems Limited)
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -12,19 +12,37 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the License.
 
-
+from prometheus_client import Counter, Histogram
 from th2_grpc_common.common_pb2 import RawMessageBatch, RawMessage
 
-from th2_common.schema.message.configuration.queue_configuration import QueueConfiguration
 from th2_common.schema.message.impl.rabbitmq.abstract_rabbit_batch_subscriber import AbstractRabbitBatchSubscriber, \
     Metadata
-from th2_common.schema.message.impl.rabbitmq.configuration.rabbitmq_configuration import RabbitMQConfiguration
+from th2_common.schema.metrics.common_metrics import CommonMetrics
 
 
 class RabbitRawBatchSubscriber(AbstractRabbitBatchSubscriber):
+    INCOMING_RAW_MSG_BATCH_QUANTITY = Counter('th2_mq_incoming_raw_msg_batch_quantity',
+                                              'Quantity of incoming raw message batches')
+    INCOMING_RAW_MSG_QUANTITY = Counter('th2_mq_incoming_raw_msg_quantity',
+                                        'Quantity of incoming raw messages')
+    RAW_MSG_PROCESSING_TIME = Histogram('th2_mq_raw_msg_processing_time',
+                                        'Time of processing raw messages',
+                                        buckets=CommonMetrics.DEFAULT_BUCKETS)
 
     __MESSAGE_TYPE = 'raw'
 
+    def get_delivery_counter(self) -> Counter:
+        return self.INCOMING_RAW_MSG_BATCH_QUANTITY
+
+    def get_content_counter(self) -> Counter:
+        return self.INCOMING_RAW_MSG_QUANTITY
+
+    def get_processing_timer(self) -> Histogram:
+        return self.RAW_MSG_PROCESSING_TIME
+
+    def extract_count_from(self, message: RawMessageBatch):
+        return len(self.get_messages(message))
+
     def get_messages(self, batch: RawMessageBatch) -> list:
         return batch.messages
 
